import { NavigationInstruction, PipelineResult } from "aurelia-router";

export declare class PiApp
{
	/**
	 * Current instance of {PitayaApp}.
	 */
	public static instance: PiApp;

	/**
	 * @bindable
	 * Event callback - Gets called if the app goes online.
	 */
	public onOnline: ( component: PiApp ) => void;

	/**
	 * @bindable
	 * Event callback - Gets called if the app goes offline.
	 */
	public onOffline: ( component: PiApp ) => void;

	/**
	 * @bindable
	 * Prevents user from interacting with this custom element and all of its child components.
	 */
	public noInteraction: boolean;

	/**
	 * @bindable
	 * Sets the status bar color of the browser (mobile).
	 */
	public statusBarColor: string;

	/**
	 * Navigates to another view/route.
	 */
	public navigate( routeName: string, options?: any ): Promise<boolean>;

	/**
	 * Navigates to another view/route.
	 * Makes it possible to pass URL parameters to the next view.
	 */
	public navigateToRoute( routeName: string, params?: object, options?: any ): Promise<boolean>;

	/**
	 * Navigates to the previous view/route;
	 */
	public navigateBack(): Promise<void>;
}

/**
 * Navigates to another view/route.
 */
export declare function navigate( routeName: string, options?: any ): Promise<boolean>;

/**
 * Navigates to another view/route.
 * Makes it possible to pass URL parameters to the next view.
 */
export declare function navigateToRoute( routeName: string, params?: object, options?: any ): Promise<boolean>;

/**
 * Navigates to the previous view/route;
 */
export declare function navigateBack(): Promise<void>;

export interface NavigationPipelineProccessingResult
{
	instruction: NavigationInstruction;
}

export interface NavigationPipelineSuccessResult
{
	instruction: NavigationInstruction;
	result: PipelineResult;
}

export interface RouteSettings
{
	level: number;
}