"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const aurelia_fetch_client_1 = require("aurelia-fetch-client");
const aurelia_framework_1 = require("aurelia-framework");
const aurelia_router_1 = require("aurelia-router");
const configuration_1 = require("../configuration");
const httpClient = new aurelia_fetch_client_1.HttpClient();
const logger = aurelia_framework_1.LogManager.getLogger("Pitaya:Decorators");
exports.onlyIfFunctions = {
    "online"() {
        return navigator.onLine;
    },
    "offline"() {
        return !navigator.onLine;
    },
    "under development"() {
        return aurelia_framework_1.Container.instance.get(configuration_1.PitayaConfiguration).development;
    }
};
exports.onlyIf = {
    instanceHasProperties(...instanceProperties) {
        return function (target, propertyKey, descriptor) {
            const oldValue = descriptor.value;
            descriptor.value = function () {
                const hasProperty = instanceProperties.some(arg => this.hasOwnProperty(arg));
                if (!hasProperty) {
                    return;
                }
                return oldValue.apply(this, arguments);
            };
            return descriptor;
        };
    },
    is(condition) {
        return function (target, propertyKey, descriptor) {
            const oldValue = descriptor.value;
            descriptor.value = function (...args) {
                try {
                    const callable = typeof condition === "function" ? condition : exports.onlyIfFunctions[condition];
                    if (!callable.call(this, this)) {
                        return;
                    }
                    return oldValue.call(this, ...args);
                }
                catch (error) {
                    logger.error(`While trying to apply onlyIf.is() decorator on method '${propertyKey}()'.`);
                }
            };
            return descriptor;
        };
    }
};
exports.view = {
    redirect(routeConfig, condition) {
        return function (constructor) {
            return class extends constructor {
                canActivate() {
                    if (!condition.call(this, this)) {
                        return true;
                    }
                    const { route, params, options } = routeConfig;
                    return new aurelia_router_1.RedirectToRoute(route, params, options);
                }
            };
        };
    }
};
exports.app = {
    router({ title, routesConfig, unknownRoutes, callback }) {
        return function (constructor) {
            return class extends constructor {
                configureRouter(config) {
                    return __awaiter(this, void 0, void 0, function* () {
                        const routes = yield getRoutes(routesConfig);
                        const mainRoute = routes.find(route => route.name === unknownRoutes) || routes[0];
                        config.title = title;
                        config.map(routes);
                        config.mapUnknownRoutes(mainRoute.moduleId);
                        callback && callback(config);
                    });
                }
            };
        };
    }
};
const getRoutes = function (routesConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        if (typeof routesConfig === "string") {
            const result = yield httpClient.fetch(aurelia_framework_1.PLATFORM.moduleName(routesConfig));
            const { routes } = yield result.json();
            return routes;
        }
        return routesConfig;
    });
};

//# sourceMappingURL=decorators.js.map
