var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { autoinject, } from "aurelia-dependency-injection";
import { EventAggregator } from "aurelia-event-aggregator";
import { LogManager, viewResources } from "aurelia-framework";
import { PLATFORM } from "aurelia-pal";
import { Router } from "aurelia-router";
import { bindable, usePropertyTypeForBindable, usePropertyTypeForObservable } from "aurelia-typed-observable-plugin";
import { createElement } from "../helpers/utils";
usePropertyTypeForBindable(true);
usePropertyTypeForObservable(true);
const META_THEME_COLOR_SELECTOR = "meta[name=theme-color]";
const META_THEME_COLOR_ELEMENT_STRING = "<meta name='theme-color' value='#FFFFFF'>";
const logger = LogManager.getLogger("Pitaya:App");
let currentInstance;
let PiApp = class PiApp {
    constructor(_eventAggregator, _router) {
        this._eventAggregator = _eventAggregator;
        this._router = _router;
        this._transitionAnimationClass = "pi-app--transition-equal-to-equal";
        this._isOnline = navigator.onLine;
        this._scopedOnlineMethod = this._onOnline.bind(this);
        this._scopedOfflineMethod = this._onOffline.bind(this);
    }
    static get instance() {
        return currentInstance;
    }
    navigate(routeName, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = this._router.navigate(routeName, options);
            yield new Promise(resolve => this._eventAggregator.subscribeOnce("router:navigation:complete", resolve));
            return result;
        });
    }
    navigateToRoute(routeName, params, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = this._router.navigateToRoute(routeName, params, options);
            yield new Promise(resolve => this._eventAggregator.subscribeOnce("router:navigation:complete", resolve));
            return result;
        });
    }
    navigateBack() {
        return __awaiter(this, void 0, void 0, function* () {
            this._router.navigateBack();
            yield new Promise(resolve => this._eventAggregator.subscribeOnce("router:navigation:complete", resolve));
        });
    }
    statusBarColorChanged(value) {
        if (!this._themeColorMetaElement) {
            return;
        }
        this._themeColorMetaElement.setAttribute("value", value);
    }
    created() {
        if (currentInstance) {
            throw new Error("ERROR  [Pitaya:PitayaApp]  It is not allowed to have multiple {PitayaApp}/<pi-app> custom elements at a time. You have first to detach the current one from the DOM.");
        }
        currentInstance = this;
        this._routeProcessingSubscribtion = this._eventAggregator.subscribe("router:navigation:processing", this._handleRouteProcessing.bind(this));
    }
    bind() {
        this.statusBarColorChanged(this.statusBarColor);
        const metaElement = document.querySelector(META_THEME_COLOR_SELECTOR);
        if (!metaElement) {
            this._themeColorMetaElement = metaElement ? metaElement : document.head.appendChild(createElement(META_THEME_COLOR_ELEMENT_STRING));
            this.statusBarColor && this.statusBarColorChanged(this.statusBarColor);
            return;
        }
        this._themeColorMetaElement = metaElement;
        !metaElement.hasAttribute("value") && this.statusBarColorChanged(this.statusBarColor || "#FFFFFF");
    }
    attached() {
        window.addEventListener("online", this._scopedOnlineMethod);
        window.addEventListener("offline", this._scopedOfflineMethod);
    }
    detached() {
        window.removeEventListener("online", this._scopedOnlineMethod);
        window.removeEventListener("offline", this._scopedOfflineMethod);
    }
    unbind() {
        this._routeProcessingSubscribtion.dispose();
        currentInstance = undefined;
    }
    _onOnline() {
        return __awaiter(this, void 0, void 0, function* () {
            this._isOnline = true;
            this.onOnline && this.onOnline({ component: this });
        });
    }
    _onOffline() {
        return __awaiter(this, void 0, void 0, function* () {
            this._isOnline = false;
            this.onOffline && this.onOffline({ component: this });
        });
    }
    _handleRouteProcessing({ instruction }) {
        if (!instruction.previousInstruction) {
            return;
        }
        try {
            const previousLevel = (instruction.previousInstruction.config.navModel.settings.level || 0);
            const nextLevel = (instruction.config.navModel.settings.level || 0);
            if (previousLevel > nextLevel) {
                return this._transitionAnimationClass = "pi-app--transition-lower-to-higher";
            }
            else if (previousLevel < nextLevel) {
                return this._transitionAnimationClass = "pi-app--transition-higher-to-lower";
            }
            this._transitionAnimationClass = "pi-app--transition-equal-to-equal";
        }
        catch (error) {
            logger.error(`Route '${instruction.config.route}' has not been found or has false configuration.`, error);
        }
    }
};
__decorate([
    bindable,
    __metadata("design:type", Function)
], PiApp.prototype, "onOnline", void 0);
__decorate([
    bindable,
    __metadata("design:type", Function)
], PiApp.prototype, "onOffline", void 0);
__decorate([
    bindable,
    __metadata("design:type", Boolean)
], PiApp.prototype, "noInteraction", void 0);
__decorate([
    bindable,
    __metadata("design:type", String)
], PiApp.prototype, "statusBarColor", void 0);
PiApp = __decorate([
    autoinject,
    viewResources(PLATFORM.moduleName("./pi-app.css")),
    __metadata("design:paramtypes", [EventAggregator,
        Router])
], PiApp);
export { PiApp };
export function navigate(routeName, options) {
    return PiApp.instance.navigate(routeName, options);
}
export function navigateToRoute(routeName, params, options) {
    return PiApp.instance.navigateToRoute(routeName, params, options);
}
export function navigateBack() {
    return PiApp.instance.navigateBack();
}

//# sourceMappingURL=pi-app.js.map
