import { Container } from "aurelia-framework";

export declare class PiView
{
	/**
	 * Inner HTML element which holds the actual content.
	 * Also the <slot> content gets projected there.
	 */
	public readonly innerElement: HTMLElement;

	/**
	 * @bindable
	 * Prevents scrolling
	 */
	public noScrolling: boolean;

	/**
	 * @bindable
	 * Prevents user from interacting with this custom element and all of its child components.
	 */
	public noInteraction: boolean;

	/**
	 * @bindable
	 * Event callback - Gets called if the app goes online.
	 */
	public onOnline: ( component: PiView ) => void;

	/**
	 * @bindable
	 * Event callback - Gets called if the app goes offline.
	 */
	public onOffline: ( component: PiView ) => void;

	/**
	 * @bindable
	 * Event callback - Gets called when the view transition animation has been completed.
	 */
	public onAnimated: ( component: PiView ) => void;

	/**
	 * @bindable
	 * Event callback - Gets called when this custom element and its child elements have been fully loaded.
	 */
	public onReady: ( component: PiView ) => void;

	/**
	 * Scrolls to a secific position or element.
	 */
	public scrollTo( target: number | HTMLElement, offset?: number ): void;
}