import { Container, PLATFORM } from "aurelia-framework";
import { coerceFunctions, usePropertyTypeForBindable, usePropertyTypeForObservable } from "aurelia-typed-observable-plugin";
import { PitayaConfiguration } from "./configuration";
let initialized = false;
export function configure(frameworkConfig, callback) {
    if (initialized) {
        return;
    }
    frameworkConfig.plugin(PLATFORM.moduleName("aurelia-animator-css"))
        .plugin(PLATFORM.moduleName("aurelia-fetch-client"))
        .plugin(PLATFORM.moduleName("aurelia-typed-observable-plugin"))
        .globalResources([
        PLATFORM.moduleName("./elements/pi-app"),
        PLATFORM.moduleName("./elements/pi-view"),
    ])
        .postTask(() => {
        coerceFunctions.boolean = value => value === undefined ? value : value !== false;
        coerceFunctions.string = value => value === undefined ? value : value.toString();
        coerceFunctions.number = value => value === undefined ? value : parseFloat(value);
        coerceFunctions.Function = coerceFunctions.function;
        coerceFunctions.numberOrString = value => {
            if (value === undefined) {
                return;
            }
            const toNumber = parseFloat(value);
            return isNaN(toNumber) ? value.toString() : toNumber;
        };
    });
    usePropertyTypeForBindable(true);
    usePropertyTypeForObservable(true);
    const config = Container.instance.get(PitayaConfiguration);
    callback instanceof Function && callback(config);
    initialized = true;
    config.initialized = true;
}
export * from "./elements/pi-app";
export * from "./elements/pi-view";
export * from "./helpers/decorators";
export * from "./helpers/utils";
export * from "./configuration";

//# sourceMappingURL=index.js.map
